# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: functionblock/v1alpha1/io4edge_functionblock.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2functionblock/v1alpha1/io4edge_functionblock.proto\x12\rfunctionblock\x1a\x19google/protobuf/any.proto\"\x18\n\x07\x43ontext\x12\r\n\x05value\x18\x01 \x01(\t\"\xe3\x01\n\x07\x43ommand\x12\'\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x16.functionblock.Context\x12\x35\n\rConfiguration\x18\x02 \x01(\x0b\x32\x1c.functionblock.ConfigurationH\x00\x12\x39\n\x0f\x66unctionControl\x18\x03 \x01(\x0b\x32\x1e.functionblock.FunctionControlH\x00\x12\x35\n\rstreamControl\x18\x04 \x01(\x0b\x32\x1c.functionblock.StreamControlH\x00\x42\x06\n\x04type\"\xe4\x01\n\rConfiguration\x12@\n functionSpecificConfigurationSet\x18\n \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x12@\n functionSpecificConfigurationGet\x18\x14 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x12\x45\n%functionSpecificConfigurationDescribe\x18\x1e \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x42\x08\n\x06\x61\x63tion\"\xa3\x01\n\x0f\x46unctionControl\x12\x42\n\"functionSpecificFunctionControlSet\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x12\x42\n\"functionSpecificFunctionControlGet\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x42\x08\n\x06\x61\x63tion\"\xbb\x01\n\x12StreamControlStart\x12\x15\n\rbucketSamples\x18\x01 \x01(\x07\x12\x19\n\x11keepaliveInterval\x18\x02 \x01(\x07\x12\x17\n\x0f\x62ufferedSamples\x18\x03 \x01(\x07\x12@\n\"functionSpecificStreamControlStart\x18\x04 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x18\n\x10low_latency_mode\x18\x05 \x01(\x08\"\x13\n\x11StreamControlStop\"\x7f\n\rStreamControl\x12\x32\n\x05start\x18\x01 \x01(\x0b\x32!.functionblock.StreamControlStartH\x00\x12\x30\n\x04stop\x18\x02 \x01(\x0b\x32 .functionblock.StreamControlStopH\x00\x42\x08\n\x06\x61\x63tion\"\x16\n\x05\x45rror\x12\r\n\x05\x65rror\x18\x01 \x01(\t\"\xec\x01\n\x15\x43onfigurationResponse\x12@\n functionSpecificConfigurationSet\x18\n \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x12@\n functionSpecificConfigurationGet\x18\x14 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x12\x45\n%functionSpecificConfigurationDescribe\x18\x1e \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x42\x08\n\x06\x61\x63tion\"\xab\x01\n\x17\x46unctionControlResponse\x12\x42\n\"functionSpecificFunctionControlSet\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x12\x42\n\"functionSpecificFunctionControlGet\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x42\x08\n\x06\x61\x63tion\"\x17\n\x15StreamControlResponse\"u\n\nStreamData\x12\x1b\n\x13\x64\x65liveryTimestampUs\x18\x01 \x01(\x06\x12\x10\n\x08sequence\x18\x02 \x01(\x07\x12\x38\n\x1a\x66unctionSpecificStreamData\x18\n \x01(\x0b\x32\x14.google.protobuf.Any\"\xf5\x02\n\x08Response\x12\'\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x16.functionblock.Context\x12%\n\x06status\x18\x02 \x01(\x0e\x32\x15.functionblock.Status\x12#\n\x05\x65rror\x18\x03 \x01(\x0b\x32\x14.functionblock.Error\x12=\n\rConfiguration\x18\x04 \x01(\x0b\x32$.functionblock.ConfigurationResponseH\x00\x12\x41\n\x0f\x66unctionControl\x18\x05 \x01(\x0b\x32&.functionblock.FunctionControlResponseH\x00\x12=\n\rstreamControl\x18\x06 \x01(\x0b\x32$.functionblock.StreamControlResponseH\x00\x12+\n\x06stream\x18\x07 \x01(\x0b\x32\x19.functionblock.StreamDataH\x00\x42\x06\n\x04type*\xf5\x01\n\x06Status\x12\x06\n\x02OK\x10\x00\x12\x14\n\x10UNSPECIFIC_ERROR\x10\x01\x12\x13\n\x0fUNKNOWN_COMMAND\x10\x02\x12\x13\n\x0fNOT_IMPLEMENTED\x10\x03\x12\x10\n\x0cWRONG_CLIENT\x10\x04\x12\x15\n\x11INVALID_PARAMETER\x10\x05\x12\x0c\n\x08HW_FAULT\x10\x06\x12\x1a\n\x16STREAM_ALREADY_STARTED\x10\x07\x12\x1a\n\x16STREAM_ALREADY_STOPPED\x10\x08\x12\x17\n\x13STREAM_START_FAILED\x10\t\x12\x1b\n\x17TEMPORARILY_UNAVAILABLE\x10\nB\x18Z\x16\x66unctionblock/v1alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'functionblock.v1alpha1.io4edge_functionblock_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\026functionblock/v1alpha1'
  _globals['_STATUS']._serialized_start=2047
  _globals['_STATUS']._serialized_end=2292
  _globals['_CONTEXT']._serialized_start=96
  _globals['_CONTEXT']._serialized_end=120
  _globals['_COMMAND']._serialized_start=123
  _globals['_COMMAND']._serialized_end=350
  _globals['_CONFIGURATION']._serialized_start=353
  _globals['_CONFIGURATION']._serialized_end=581
  _globals['_FUNCTIONCONTROL']._serialized_start=584
  _globals['_FUNCTIONCONTROL']._serialized_end=747
  _globals['_STREAMCONTROLSTART']._serialized_start=750
  _globals['_STREAMCONTROLSTART']._serialized_end=937
  _globals['_STREAMCONTROLSTOP']._serialized_start=939
  _globals['_STREAMCONTROLSTOP']._serialized_end=958
  _globals['_STREAMCONTROL']._serialized_start=960
  _globals['_STREAMCONTROL']._serialized_end=1087
  _globals['_ERROR']._serialized_start=1089
  _globals['_ERROR']._serialized_end=1111
  _globals['_CONFIGURATIONRESPONSE']._serialized_start=1114
  _globals['_CONFIGURATIONRESPONSE']._serialized_end=1350
  _globals['_FUNCTIONCONTROLRESPONSE']._serialized_start=1353
  _globals['_FUNCTIONCONTROLRESPONSE']._serialized_end=1524
  _globals['_STREAMCONTROLRESPONSE']._serialized_start=1526
  _globals['_STREAMCONTROLRESPONSE']._serialized_end=1549
  _globals['_STREAMDATA']._serialized_start=1551
  _globals['_STREAMDATA']._serialized_end=1668
  _globals['_RESPONSE']._serialized_start=1671
  _globals['_RESPONSE']._serialized_end=2044
# @@protoc_insertion_point(module_scope)



# SPDX-License-Identifer: Apache-2.0
from io4edge_client.functionblock import Client as FbClient
import io4edge_client.api.binaryIoTypeC.python.binaryIoTypeC.v1alpha1.binaryIoTypeC_pb2 as Pb
import io4edge_client.api.io4edge.python.functionblock.v1alpha1.io4edge_functionblock_pb2 as FbPb


class Client:
    """
    binaryIoTypeC functionblock client.
    @param addr: address of io4edge function block (mdns name or "ip:port" address)
    @param command_timeout: timeout for commands in seconds
    """

    def __init__(self, addr: str, command_timeout=5):
        self._fb_client = FbClient("_io4edge_binaryIoTypeC._tcp", addr, command_timeout)

    def upload_configuration(self, config: Pb.ConfigurationSet):
        """
        Upload the configuration to the binaryIoTypeC functionblock.
        @param config: configuration to upload
        @raises RuntimeError: if the command fails
        @raises TimeoutError: if the command times out
        """
        self._fb_client.upload_configuration(config)

    def download_configuration(self) -> Pb.ConfigurationGetResponse:
        """
        Download the configuration from the binaryIoTypeC functionblock.
        @return: actual configuration
        @raises RuntimeError: if the command fails
        @raises TimeoutError: if the command times out
        """
        fs_response = Pb.ConfigurationGetResponse()
        self._fb_client.download_configuration(Pb.ConfigurationGet(), fs_response)
        return fs_response

    def describe(self) -> Pb.ConfigurationDescribeResponse:
        """
        Get the description from the binaryIoTypeC functionblock.
        @return: description from the binaryIoTypeC functionblock
        @raises RuntimeError: if the command fails
        @raises TimeoutError: if the command times out
        """
        fs_response = Pb.ConfigurationDescribeResponse()
        self._fb_client.describe(Pb.ConfigurationDescribe(), fs_response)
        return fs_response

    def set_output(self, channel: int, state: bool):
        """
        Set the state of a single output.
        @param channel: channel number
        @param state: state to set. a "true" state sets the output to high, a "false" state sets the output to low
        @raises RuntimeError: if the command fails
        @raises TimeoutError: if the command times out
        """
        fs_cmd = Pb.FunctionControlSet()
        fs_cmd.single.channel = channel
        fs_cmd.single.state = state
        self._fb_client.function_control_set(fs_cmd, Pb.FunctionControlSetResponse())

    def set_all_outputs(self, states: int, mask: int):
        """
        Set the state of all or a group of output channels.
        @param states: binary coded map of outputs. 0 means switch low, 1 means switch high, LSB is Channel0
        @param mask: binary coded map of outputs to be set. 0 means do not change, 1 means change, LSB is Channel0
        @raises RuntimeError: if the command fails
        @raises TimeoutError: if the command times out
        """
        fs_cmd = Pb.FunctionControlSet()
        fs_cmd.all.states = states
        fs_cmd.all.mask = mask
        self._fb_client.function_control_set(fs_cmd, Pb.FunctionControlSetResponse())

    def input(self, channel: int):
        """
        Get the state of a single channel, regardless whether its configured as input or output)
        and the diagnostic info of a single channel.
        State "true" state means the input is high, a "false" state means the input is low.
        The returned diagnostic info is a bitfield containing diagnostic bits.
        @param channel: channel number
        @return: state of the input, diagnostic info.
        @raises RuntimeError: if the command fails
        @raises TimeoutError: if the command times out
        """
        fs_cmd = Pb.FunctionControlGet()
        fs_cmd.single.channel = channel
        fs_response = Pb.FunctionControlGetResponse()
        self._fb_client.function_control_get(fs_cmd, fs_response)
        return fs_response.single.state, fs_response.single.diag

    def all_inputs(self) -> Pb.FunctionControlGetResponse:
        """
        Get the state of all channels, regardless whether they are configured as input or output.
        Each bit in the returned state corresponds to one channel, bit0 being channel 0.
        The bit is false if the pin level is low, true otherwise.
        diag is a slice with bitfields containing diagnostic bits for each channel.
        """
        fs_cmd = Pb.FunctionControlGet()
        fs_cmd.all.CopyFrom(Pb.GetAll())
        fs_response = Pb.FunctionControlGetResponse()
        self._fb_client.function_control_get(fs_cmd, fs_response)
        return fs_response.all

    def start_stream(
        self, config: Pb.StreamControlStart, fb_config: FbPb.StreamControl
    ):
        """
        Start streaming of transitions.
        @param config: filter configuration of the stream
        @param fb_config: functionblock generic configuration of the stream
        @raises RuntimeError: if the command fails
        @raises TimeoutError: if the command times out
        """
        self._fb_client.start_stream(config, fb_config)

    def stop_stream(self):
        """
        Stop streaming of transitions.
        @raises RuntimeError: if the command fails
        @raises TimeoutError: if the command times out
        """
        self._fb_client.stop_stream()

    def read_stream(self, timeout=None):
        """
        Read the next message from the stream.
        @param timeout: timeout in seconds
        @return: functionblock generic stream data (deliveryTimestampUs, sequence), binaryIoTypeC specific stream data
        @raises TimeoutError: if no data is available within the timeout
        """
        stream_data = Pb.StreamData()
        generic_stream_data = self._fb_client.read_stream(timeout, stream_data)
        return generic_stream_data, stream_data

    def close(self):
        """
        Close the connection to the function block, terminate read thread.
        After calling this method, the object is no longer usable.
        """
        self._fb_client.close()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/tracelet.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11v1/tracelet.proto\x12\x08tracelet\x1a\x1fgoogle/protobuf/timestamp.proto\"\xe7\n\n\x10TraceletToServer\x12\n\n\x02id\x18\x01 \x01(\x05\x12/\n\x0b\x64\x65livery_ts\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0btracelet_id\x18\x03 \x01(\t\x12\x10\n\x08ignition\x18\x04 \x01(\x08\x12\x37\n\x08location\x18\x05 \x01(\x0b\x32#.tracelet.TraceletToServer.LocationH\x00\x1a\xad\t\n\x08Location\x12\x36\n\x04gnss\x18\x01 \x01(\x0b\x32(.tracelet.TraceletToServer.Location.Gnss\x12\x34\n\x03uwb\x18\x02 \x01(\x0b\x32\'.tracelet.TraceletToServer.Location.Uwb\x12\x38\n\x05\x66used\x18\x07 \x01(\x0b\x32).tracelet.TraceletToServer.Location.Fused\x12@\n\tdirection\x18\x03 \x01(\x0e\x32-.tracelet.TraceletToServer.Location.Direction\x12\r\n\x05speed\x18\x04 \x01(\x01\x12\x0f\n\x07mileage\x18\x05 \x01(\x05\x12\x13\n\x0btemperature\x18\x06 \x01(\x01\x12\x46\n\x0c\x61\x63\x63\x65leration\x18\x08 \x01(\x0b\x32\x30.tracelet.TraceletToServer.Location.Acceleration\x1a\xcd\x01\n\x04Gnss\x12\r\n\x05valid\x18\x01 \x01(\x08\x12\x10\n\x08latitude\x18\x02 \x01(\x01\x12\x11\n\tlongitude\x18\x03 \x01(\x01\x12\x10\n\x08\x61ltitude\x18\x04 \x01(\x01\x12\x0b\n\x03\x65ph\x18\x05 \x01(\x01\x12\x0b\n\x03\x65pv\x18\x06 \x01(\x01\x12\x10\n\x08\x66ix_type\x18\x07 \x01(\x05\x12\x13\n\x0bhead_motion\x18\x08 \x01(\x01\x12\x14\n\x0chead_vehicle\x18\t \x01(\x01\x12\x12\n\nhead_valid\x18\n \x01(\r\x12\x14\n\x0cground_speed\x18\x0b \x01(\x01\x1a\xd6\x01\n\x03Uwb\x12\r\n\x05valid\x18\x01 \x01(\x08\x12\t\n\x01x\x18\x02 \x01(\x01\x12\t\n\x01y\x18\x03 \x01(\x01\x12\t\n\x01z\x18\x04 \x01(\x01\x12\x0f\n\x07site_id\x18\x05 \x01(\r\x12\x1a\n\x12location_signature\x18\x06 \x01(\x06\x12\x0b\n\x03\x65ph\x18\x07 \x01(\x01\x12\x10\n\x08\x66ix_type\x18\x08 \x01(\x05\x12\x13\n\x0bhead_motion\x18\t \x01(\x01\x12\x14\n\x0chead_vehicle\x18\n \x01(\x01\x12\x12\n\nhead_valid\x18\x0b \x01(\r\x12\x14\n\x0cground_speed\x18\x0c \x01(\x01\x1a\xaf\x01\n\x05\x46used\x12\r\n\x05valid\x18\x01 \x01(\x08\x12\x10\n\x08latitude\x18\x02 \x01(\x01\x12\x11\n\tlongitude\x18\x03 \x01(\x01\x12\x10\n\x08\x61ltitude\x18\x04 \x01(\x01\x12\x0b\n\x03\x65ph\x18\x05 \x01(\x01\x12\x13\n\x0bhead_motion\x18\x06 \x01(\x01\x12\x14\n\x0chead_vehicle\x18\x07 \x01(\x01\x12\x12\n\nhead_valid\x18\x08 \x01(\r\x12\x14\n\x0cground_speed\x18\t \x01(\x01\x1a\x95\x01\n\x0c\x41\x63\x63\x65leration\x12\r\n\x05x_max\x18\x01 \x01(\x01\x12\r\n\x05y_max\x18\x02 \x01(\x01\x12\r\n\x05z_max\x18\x03 \x01(\x01\x12\r\n\x05x_min\x18\x04 \x01(\x01\x12\r\n\x05y_min\x18\x05 \x01(\x01\x12\r\n\x05z_min\x18\x06 \x01(\x01\x12\r\n\x05x_avg\x18\x07 \x01(\x01\x12\r\n\x05y_avg\x18\x08 \x01(\x01\x12\r\n\x05z_avg\x18\t \x01(\x01\"G\n\tDirection\x12\x10\n\x0cNO_DIRECTION\x10\x00\x12\x13\n\x0f\x43\x41\x42_A_DIRECTION\x10\x01\x12\x13\n\x0f\x43\x41\x42_B_DIRECTION\x10\x02\x42\x06\n\x04typeB\x0cZ\n./traceletb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'v1.tracelet_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\n./tracelet'
  _globals['_TRACELETTOSERVER']._serialized_start=65
  _globals['_TRACELETTOSERVER']._serialized_end=1448
  _globals['_TRACELETTOSERVER_LOCATION']._serialized_start=243
  _globals['_TRACELETTOSERVER_LOCATION']._serialized_end=1440
  _globals['_TRACELETTOSERVER_LOCATION_GNSS']._serialized_start=615
  _globals['_TRACELETTOSERVER_LOCATION_GNSS']._serialized_end=820
  _globals['_TRACELETTOSERVER_LOCATION_UWB']._serialized_start=823
  _globals['_TRACELETTOSERVER_LOCATION_UWB']._serialized_end=1037
  _globals['_TRACELETTOSERVER_LOCATION_FUSED']._serialized_start=1040
  _globals['_TRACELETTOSERVER_LOCATION_FUSED']._serialized_end=1215
  _globals['_TRACELETTOSERVER_LOCATION_ACCELERATION']._serialized_start=1218
  _globals['_TRACELETTOSERVER_LOCATION_ACCELERATION']._serialized_end=1367
  _globals['_TRACELETTOSERVER_LOCATION_DIRECTION']._serialized_start=1369
  _globals['_TRACELETTOSERVER_LOCATION_DIRECTION']._serialized_end=1440
# @@protoc_insertion_point(module_scope)
